@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.35';
+our $VERSION = '0.2.36';
 
 1;
 
@@ -1403,51 +1403,56 @@ Outthentic provides some helpers and variables:
 
 =over
 
-=item -
+=item *
 
 centos5
 
 
-=item -
+=item *
 
 centos6
 
 
-=item -
+=item *
 
 centos7
 
 
-=item -
+=item *
 
 ubuntu
 
 
-=item -
+=item *
 
 debian
 
 
-=item -
+=item *
 
 minoca
 
 
-=item -
+=item *
 
 archlinux
 
 
-=item -
+=item *
 
 fedora
 
 
-=item -
+=item *
 
 amazon
 
 
+=item *
+
+alpine
+
+
 =back
 
 
